@@ -15,7 +15,7 @@ class BaseRapidModel(QtGui.QStandardItemModel):
 		self.setHeaderData(0, QtCore.Qt.Horizontal, "Name")
 		self.setHeaderData(1, QtCore.Qt.Horizontal, "Tags")
 		i = 0
-		for p in filter( dataFunction, main.rapid.get_packages() ):
+		for p in filter( dataFunction, main.rapid.packages() ):
 			self.insertRow(i)
 			self.setData(self.index(i, 0), p.name)
 			self.setData(self.index(i, 1), ', '.join(p.tags))
